.. numdisplay documentation master file, created by
   sphinx-quickstart on Wed Sep 12 14:53:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Numdisplay's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   numdisplay
   displaydev
   zscale
   overlay
   ichar
   imconfig

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

